@define-color notebook_tab_gradient_b shade (@bg_color, 0.98);

GeditWindow .pane-separator,
GeditWindow .pane-separator:hover {
}

GeditPanel.title GtkLabel {
}

GeditPanel .toolbar {
    border-style: none;
    background-color: transparent;
}

GeditDocumentsPanel .view {
}

GeditDocumentsPanel .view:backdrop {
}

GeditWindow .notebook {
    padding: 1px;
    border-radius: 1px;
}

GeditPanel .notebook {
    padding: 3px;
    border-radius: 1px;
}

GeditPanel .notebook tab,
GeditWindow .notebook tab {
    border-radius: 3px;
}
