/* default color scheme */
@define-color bg_color #f6f4f2;
@define-color fg_color #4c4c4c;
@define-color base_color #ffffff;
@define-color text_color #3C3C3C;
@define-color selected_bg_color #f07746;
@define-color selected_fg_color #ffffff;
@define-color tooltip_bg_color #000000;
@define-color tooltip_fg_color #ffffff;

/* misc colors used by gtk+ */
@define-color info_fg_color rgb (181, 171, 156);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (173, 120, 41);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (97, 122, 214);
@define-color question_bg_color rgb (138, 173, 212);
@define-color error_fg_color rgb (166, 38, 38);
@define-color error_bg_color rgb (237, 54, 54);
@define-color link_color #4a90d9;
@define-color error_color #cc0000;

/* theme common colors */
@define-color button_bg_color shade (mix (#dfd7cf, #cdcdcd, 0.6), 1.06);
@define-color button_insensitive_bg_color mix (@button_bg_color, @bg_color, 0.6);
@define-color dark_bg_color #dfd7cf;
@define-color dark_fg_color @fg_color;
@define-color transparent rgba (0, 0, 0, 0);
@define-color backdrop_selected_bg_color shade (@bg_color, 0.92);
@define-color backdrop_selected_fg_color @fg_color;

@import url("gtk-widgets.css");
@import url("gtk-widgets-backdrop.css");
@import url("apps/gedit.css");
@import url("apps/gnome-panel.css");
@import url("apps/gnome-terminal.css");
@import url("apps/nautilus.css");
@import url("apps/unity.css");
