/* Fallback Mode Panel */
PanelWidget,
PanelApplet,
PanelToplevel {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.5)),
                                     to (shade (@dark_bg_color, 1.05)));
    padding: 0;

    color: @dark_fg_color;
}

PanelApplet {
    border-width: 0;
}

PanelSeparator {
    border-width: 0;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.5)),
                                     to (shade (@dark_bg_color, 1.05)));

    color: @dark_fg_color;
}

.gnome-panel-menu-bar,
PanelApplet > GtkMenuBar.menubar,
PanelApplet > GtkMenuBar.menubar.menuitem,
PanelMenuBar.menubar,
PanelMenuBar.menubar.menuitem {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.5)),
                                     to (shade (@dark_bg_color, 1.05)));
}

PanelAppletFrame { 
    background-color: @dark_bg_color;
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.5)),
                                     to (shade (@dark_bg_color, 1.05)));
    border-width: 0;
}

PanelApplet .button {
    -GtkButton-inner-border: 2;

    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.5)),
                                     to (shade (@dark_bg_color, 1.05)));

    border-color: shade (@dark_bg_color, 0.78);
    border-radius: 0;
    border-width: 0 1px 0 1px;

    color: @dark_fg_color;
    text-shadow: none;

    -unico-border-gradient: none;
    -unico-glow-radius: 0;
    -unico-inner-stroke-width: 0;
    -unico-outer-stroke-width: 0;
}

PanelApplet .button:prelight:active,
PanelApplet .button:active {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 0.85)),
                                     to (shade (@dark_bg_color, 1.0))); 
    border-color: shade (@dark_bg_color, 0.78);
    border-radius: 0;
    border-width: 0 1px 0 1px;

    -unico-border-gradient: none;
    -unico-glow-radius: 0;
    -unico-inner-stroke-width: 0;
    -unico-outer-stroke-width: 0;
}

PanelApplet .button:prelight {
    background-image: -gtk-gradient (linear, left top, left bottom,
                                     from (shade (@dark_bg_color, 1.7)),
                                     to (shade (@dark_bg_color, 1.25)));
    border-color: shade (@dark_bg_color, 0.78);
    border-radius: 0;
    border-width: 0 1px 0 1px;

    -unico-border-gradient: none;
    -unico-glow-radius: 0;
    -unico-inner-stroke-width: 0;
    -unico-outer-stroke-width: 0;
}

ClockBox {
    text-shadow: 0 -1 shade (@dark_bg_color, 0.6);
}

WnckPager, WnckTasklist {
    background-color: @dark_bg_color;
}
